@@ -49,6 +49,7 @@ class Channel(virtual.Channel):
     """Azure Service Bus channel."""
 
     default_visibility_timeout = 1800  # 30 minutes.
+    default_wait_time_seconds = 5  # in seconds
     domain_format = 'kombu%(vhost)s'
     _queue_service = None
     _queue_cache = {}
@@ -92,7 +93,10 @@ class Channel(virtual.Channel):
     def _get(self, queue, timeout=None):
         """Try to retrieve a single message off ``queue``."""
         message = self.queue_service.receive_queue_message(
-            self.entity_name(queue), timeout=timeout, peek_lock=False)
+            self.entity_name(queue),
+            timeout=timeout or self.wait_time_seconds,
+            peek_lock=False
+        )
 
         if message.body is None:
             raise Empty()
@@ -145,6 +149,11 @@ class Channel(virtual.Channel):
     def queue_name_prefix(self):
         return self.transport_options.get('queue_name_prefix', '')
 
+    @cached_property
+    def wait_time_seconds(self):
+        return self.transport_options.get('wait_time_seconds',
+                                          self.default_wait_time_seconds)
+
 
 class Transport(virtual.Transport):
     """Azure Service Bus transport."""
